summaryrefslogtreecommitdiffstats
path: root/kviewshell/renderedDocumentPagePixmap.h
diff options
context:
space:
mode:
Diffstat (limited to 'kviewshell/renderedDocumentPagePixmap.h')
-rw-r--r--kviewshell/renderedDocumentPagePixmap.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kviewshell/renderedDocumentPagePixmap.h b/kviewshell/renderedDocumentPagePixmap.h
index 112650ba..5e6e79fb 100644
--- a/kviewshell/renderedDocumentPagePixmap.h
+++ b/kviewshell/renderedDocumentPagePixmap.h
@@ -13,8 +13,8 @@
#include "renderedDocumentPage.h"
-#include <qpainter.h>
-#include <qpixmap.h>
+#include <tqpainter.h>
+#include <tqpixmap.h>
// This class contains everything documentRenderer needs to know
@@ -29,28 +29,28 @@ public:
virtual ~RenderedDocumentPagePixmap();
/** Returns a pointer to the paintDevice (in most implementation
- either a QPixmap, or a QPrinter). The pointer returned is valid
+ either a TQPixmap, or a TQPrinter). The pointer returned is valid
as long as *this RenderedDocumentPage exists. This method is
used by the renderer to draw on the page. */
- virtual QPainter *getPainter();
+ virtual TQPainter *getPainter();
- /** This implementation delete the QPainter *pt (and thereby initiates the drawing) */
- virtual void returnPainter(QPainter *pt) {delete pt;}
+ /** This implementation delete the TQPainter *pt (and thereby initiates the drawing) */
+ virtual void returnPainter(TQPainter *pt) {delete pt;}
- QPixmap accessiblePixmap();
+ TQPixmap accessiblePixmap();
- void resize(const QSize& size);
+ void resize(const TQSize& size);
void resize(int width, int height);
- virtual QSize size() { return QPixmap::size(); }
- virtual int width() { return QPixmap::width(); }
- virtual int height() { return QPixmap::height(); }
+ virtual TQSize size() { return TQPixmap::size(); }
+ virtual int width() { return TQPixmap::width(); }
+ virtual int height() { return TQPixmap::height(); }
/** Returns the amount of memory used by this pixmap */
unsigned int memory();
private:
- QPixmap* _accessiblePixmap;
+ TQPixmap* _accessiblePixmap;
/** true if _accessiblePixmap needs updateing */
bool dirty;
};